@@ -1,6 +1,5 @@
 import os, string, sys, re
 import xml.dom.minidom
-import xml.parsers.expat
 from subprocess import Popen, PIPE
 from distutils import log
 
@@ -68,6 +67,7 @@ def update(pkgname, verfilename, revision_number=False, loud=False, abort_if_sna
     if not revision_number:
         cmd.append("--from-tag=^%s" % (pkgname,))
 
+    errput = None
     try:
         p = Popen(["darcs"] + cmd, stdout=PIPE, stderr=PIPE, universal_newlines=True)
     except OSError, ose:
@@ -114,11 +114,7 @@ def update(pkgname, verfilename, revision_number=False, loud=False, abort_if_sna
     # strip off trailing warning messages that darcs 2.3.1 writes to stdout
     endi = output.find("</changelog>")+len("</changelog>")
     output = output[:endi]
-    try:
-        doc = xml.dom.minidom.parseString(output)
-    except xml.parsers.expat.ExpatError, le:
-        le.args = tuple(le.args + (output,))
-        raise
+    doc = xml.dom.minidom.parseString(output)
 
     changelog = doc.getElementsByTagName("changelog")[0]
     patches = changelog.getElementsByTagName("patch")
